@@ -1,8 +1,8 @@
-### lait.R  (2011-06-26)
+### lait.R  (2012-08-19)
 ###
 ###    Correlation-Predicted t-Statistic of Lai
 ###
-### Copyright 2009-11 Verena Zuber and Korbinian Strimmer
+### Copyright 2009-12 Verena Zuber and Korbinian Strimmer
 ###
 ### Parts of the code are adopted from example code by Yinglai Lai
 ###
@@ -37,8 +37,8 @@ lait.fun = function (L, f=0.2, verbose=TRUE)
  
   function(X)
   { 
-    tmp = centroids(X, L, var.groups=FALSE, centered.data=TRUE,
-              shrink=FALSE, verbose=verbose)
+    tmp = centroids(X, L, lambda.var=0, var.groups=FALSE, 
+            centered.data=TRUE, verbose=verbose)
       
     # differences between the two groups
     diff = tmp$means[,1]-tmp$means[,2]
